<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Marrësit Edit Form");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Marrësit Edit Form");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Forma Faqe");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Ju mund të caktojë më shumë se një marrës duke i ndarë email me presje.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ruajtja e marrësit ...");
define('VIEW_FORM_TABLES_HEADING', "Shikoni tabelat e formularëve");
define('VIEW_FORM_TABLES_BTN', "Shikoni tabelat e formularëve");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Zgjidh një tabelë për të parë");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtroni mesazhet e lexuara");
?>